@@ -17,7 +17,7 @@ use Storable;
 use vars qw($VERSION $NAME);
 
 
-$VERSION = '0.076';
+$VERSION = '0.079';
 $NAME = 'String::Simrank';
 
 # Must specify a NAME and VERSION parameter. The NAME must match your module's package
@@ -39,8 +39,8 @@ String::Simrank - Rapid comparisons of many strings for k-mer similarity.
   $sr->formatdb();
   $sr->match_oligos({ query => 'query.fasta' });
 
-You may utilize  k-mers of various sizes, e.g.:
-$sr->formatdb( { wordlen => 6 } );
+  You may utilize  k-mers of various sizes, e.g.:
+  $sr->formatdb( { wordlen => 6 } );
 =cut
 
 =head1 DESCRIPTION
@@ -107,7 +107,7 @@ sub new {
        # many instances these will come directly from the command line.
     my $self = bless {}, $class;
     $self->_check_arguments_for_new($cl_args);
-    
+    # print STDERR "you are using String::Simrank version $VERSION \n";
     return $self;
 }
 
@@ -153,7 +153,7 @@ sub _check_arguments_for_new {
 	    }
             
         } else {
-            push @errors, qq (Input fasta data file not found or not readable -> "$cl_args->{'data'}");
+            push @errors, qq (Simrank.pm: Input fasta data file not found or not readable -> "$cl_args->{'data'}");
         }
         
     } else {
@@ -182,7 +182,7 @@ sub _check_arguments_for_new {
 
 =head2 formatdb({ wordlen => $int, minlen => $int, silent = $bool })
 
-  $sr->formatdb({wordlen => 8, minlen => 500, silent = 0, valid_chars = 'ACGT'})
+  $sr->formatdb({wordlen => 8, minlen => 500, silent => 0, valid_chars => 'ACGT'});
 
 From an input collection of strings (data), generates a binary file
 optimized for retrieval of k-mer similarities. The file will contain
@@ -239,7 +239,7 @@ Default is false, meaning not silent.
 
 sub formatdb {
     # Niels Larsen, November 2005.
-    # Todd Z. DeSantis, March 2006
+    # Todd Z. DeSantis, July 2010
 
     my ( $self, $cl_args) = @_;
     $self->_check_arguments_for_formatdb($cl_args);
@@ -264,9 +264,7 @@ sub formatdb {
     
     # Find the number of sequences and the longest length identifier,
     print "Counting new fasta records and measuring size of identifiers... " if not $cl_silent;   
-    # may need to abandon grep to work on Windows.
-    $seqtot = `grep -c '^>' $cl_data` || 'still counting';
-    chomp $seqtot;
+    $seqtot = _count_records($cl_data); 
     print "found $seqtot\n" if not $cl_silent;
         
     $seqnum = 0;
@@ -348,7 +346,6 @@ sub formatdb {
     # and save the word length and number of sequences (the rest can be
     # calculated)
 
-  
     eval { $bin_fh = IO::File->new( $cl_binary, 'w' ) };
     if ($@) {
 	print STDERR $@;
@@ -359,6 +356,7 @@ sub formatdb {
 	    exit;
         }
     }
+    # print STDERR Dumper($bin_fh);
     unless (defined $bin_fh) {
 	print STDERR "A filehandle to $cl_binary has not been defined\n";
 	exit;
@@ -486,6 +484,7 @@ sub formatdb {
 It checks that word length and minimum sequence length is reasonable.
 Sets silent to true by default.
 Sets pre_subst to 1 by default.
+Defines binary file name.
 If errors are found, program exits.
 Returns a hash or hash ref
 depending on the context of the method call.
@@ -545,8 +544,6 @@ sub _check_arguments_for_formatdb {
     }
     $self->{param}{wordlen} = $cl_args->{"wordlen"};
 
-
-
     if ( not defined $cl_args->{"silent"} ) {
         $cl_args->{"silent"} = 0
     }
@@ -1142,6 +1139,29 @@ sub _nearest_index
 
     return $low;
 }
+
+=head2 _count_records
+
+Counts the number of records in a fasta formated file.
+
+=cut
+
+sub _count_records
+{
+    # Todd Z. DeSantis, July 2010.
+    my ( $fasta_file ) = @_;
+
+    # Returns an integer. 
+    my $c = 0;
+    my $ffh = new IO::File $fasta_file, "r";
+    while (<$ffh>) {
+	$c++ if ($_ =~ /^\>/);
+    }
+    $ffh->close;
+    return $c;
+}
+
+
 1;
 
 =head2 _update_scores_C
